- Cached Scripts
+ Code Cache
- Given your script key,{" "}
+ Given your code key,{" "}
{scriptKey}
- , search for scripts using a script key value. For this script key
+ , search for saved code using a code key value. For this code key
there {totalCount === 1 ? "is" : "are"}{" "}
- {totalCount}{" "}
- script key {totalCount === 1 ? "value" : "values"}
+ {totalCount} code
+ key {totalCount === 1 ? "value" : "values"}
{filteredCount !== totalCount && (
<>
{" "}
diff --git a/skyvern-frontend/src/routes/workflows/workflowRun/ActionCard.tsx b/skyvern-frontend/src/routes/workflows/workflowRun/ActionCard.tsx
index 069abd90..b87ce720 100644
--- a/skyvern-frontend/src/routes/workflows/workflowRun/ActionCard.tsx
+++ b/skyvern-frontend/src/routes/workflows/workflowRun/ActionCard.tsx
@@ -66,7 +66,7 @@ function ActionCard({ action, onClick, active, index }: Props) {
- Scripted Execution
+ Code Execution
diff --git a/skyvern-frontend/src/routes/workflows/editor/utils.ts b/skyvern-frontend/src/routes/workflows/editor/utils.ts
index a120b8e2..ed78925a 100644
--- a/skyvern-frontend/src/routes/workflows/editor/utils.ts
+++ b/skyvern-frontend/src/routes/workflows/editor/utils.ts
@@ -98,10 +98,10 @@ const getInitialParameters = (workflow: WorkflowApiResponse) => {
};
/**
* Attempt to construct a valid cache key value from the workflow parameters.
*/
const constructCacheKeyValue = (
- cacheKey: string,
+ codeKey: string,
workflow: WorkflowApiResponse,
) => {
const workflowParameters = getInitialParameters(workflow)
@@ -119,14 +119,14 @@ const constructCacheKeyValue = (
continue;
}
- cacheKey = cacheKey.replace(`{{${name}}}`, value.toString());
+ codeKey = codeKey.replace(`{{${name}}}`, value.toString());
}
- if (cacheKey.includes("{") || cacheKey.includes("}")) {
+ if (codeKey.includes("{") || codeKey.includes("}")) {
return "";
}
- return cacheKey;
+ return codeKey;
};
export { constructCacheKeyValue, getInitialParameters };
@@ -98,10 +98,10 @@ const getInitialParameters = (workflow: WorkflowApiResponse) => {
};
/**
- * Attempt to construct a valid cache key value from the workflow parameters.
+ * Attempt to construct a valid code key value from the workflow parameters.
*/
const constructCacheKeyValue = (